@@ -1,7 +1,4 @@
 from instaclient.client.instaclient import InstaClient
 from instaclient.utilities import utilities
 from instaclient.errors import common
-
-__all__ = [
-    'InstaClient', 'utilities', 'common'
-]
\ No newline at end of file
+from instaclient.classes import *
\ No newline at end of file
