@@ -9,4 +9,7 @@ class ClientUrls:
 
 
 class GraphUrls:
-    NOTIFICATIONS_GURL = 'https://www.instagram.com/accounts/activity/?__a=1'
\ No newline at end of file
+    GRAPH_USER='https://www.instagram.com/{}/?__a=1'
+    GRAPH_TAGS='https://www.instagram.com/explore/tags/{}/?__a=1'
+    GRAPH_ACTIVITY = 'https://www.instagram.com/accounts/activity/?__a=1'
+    GRAPH_POST = 'https://www.instagram.com/p/{}/?__a=1'
